@@ -1,7 +1,7 @@
 package Mail::Milter::Authentication::Handler;
 use strict;
 use warnings;
-our $VERSION = '2.20200102'; # VERSION
+our $VERSION = '2.20200106'; # VERSION
 
 
 use Digest::MD5 qw{ md5_hex };
@@ -1231,13 +1231,13 @@ sub destroy_object {
     # destroyed for performance reasons
     # Resolver, however, has its error cache cleared, as this should only
     # cache errors within a single transaction.
+    return if ! $thischild->{'object'}->{$name};
     if ($name eq 'resolver' ) {
-        if ( $thischild->{'object'}->{'resolver'}->can( 'clear_error_cache' ) ) {
-            $thischild->{'object'}->{'resolver'}->clear_error_cache();
+        if ( $thischild->{'object'}->{'resolver'}->{'object'}->can( 'clear_error_cache' ) ) {
+            $thischild->{'object'}->{'resolver'}->{'object'}->clear_error_cache();
         }
     }
     return if ! $thischild->{'object'}->{$name}->{'destroy'};
-    return if ! $thischild->{'object'}->{$name};
     $self->dbgout( 'Object destroyed', $name, LOG_DEBUG );
     delete $thischild->{'object'}->{$name};
     return;
@@ -2071,7 +2071,7 @@ Mail::Milter::Authentication::Handler
 
 =head1 VERSION
 
-version 2.20200102
+version 2.20200106
 
 =head1 DESCRIPTION
 
